﻿using System;
using System.IO;
using UnityEngine;

/*
 Não é possível usar um ScriptableObject para salvar os dados.
 SOs como arquivos só existem na forma de projeto, e desaparecem
 após a build.
 Ainda funcionam e conseguem armazenar dados entre cenas, mas quando
 são desalocados da memória (por exemplo, ao fim de uma sessão),
 voltam aos seus valores iniciais.
 Ver comentários em EnemyInfo.cs para exemplos de casos de uso
 adequados para SOs.
 */
public class SaveSystem : MonoBehaviour
{
	public GameObject player;
	public string filename;

	[Serializable]
	private class SaveData
	{
		public int playerExp;
	}

	void Awake()
	{
		Debug.Log(Application.persistentDataPath);
	}

	public void Save()
	{
		var data = new SaveData();
		data.playerExp = player.GetComponent<Experience>().total;
		var serializedData = JsonUtility.ToJson(data);
		File.WriteAllText(
			Application.persistentDataPath + '/' + this.filename,
			serializedData);
	}

	public void Load()
	{
		var serializedData = File.ReadAllText(
			Application.persistentDataPath + '/' + this.filename);
		var data = JsonUtility.FromJson<SaveData>(serializedData);
		this.player.GetComponent<Experience>().total = data.playerExp;
	}

	void Update()
	{
		if (Input.GetKeyDown(KeyCode.Alpha1))
			Save();
		if (Input.GetKeyDown(KeyCode.Alpha2))
			Load();
	}
}
